@@ -125,7 +125,7 @@ def main():
         logger.info('the connection to the templates collection ("%s") is established', tmpl_coll.name)
 
         structure_template = tmpl_coll.find_one({'name': args.tmpl})['structure']
-        logger.info('a structure template ("%s") was obtained from the collection with the results', args.tmpl)
+        logger.info('a structure template ("%s") was obtained from the collection with the templates', args.tmpl)
 
         parser = SRSParser(structure_template)
         document_structure = parser.parse_docx(args.docx_path)
